@@ -1,4 +1,4 @@
-from botty.callbacks import TextCallback
+from botty.callbacks import ReplyCallback
 from botty.keyboards import InlineKeyboard
 from botty.triggers import CommandTrigger
 
@@ -6,7 +6,7 @@ from .update import UpdateHandler
 
 
 class CommandHandler(UpdateHandler):
-    def __init__(self, callback: TextCallback, command: str) -> None:
+    def __init__(self, callback: ReplyCallback, command: str) -> None:
         self._command = command
         super().__init__(callback)
 
@@ -21,5 +21,5 @@ class CommandReplyHandler(CommandHandler):
         text: str | None = None,
         keyboard: InlineKeyboard | None = None,
     ) -> None:
-        callback = TextCallback(text, keyboard)
+        callback = ReplyCallback(text, keyboard)
         super().__init__(callback, command)
