@@ -1,5 +1,5 @@
 from botty.buttons import CallbackButton
-from botty.callbacks import QueryCallback
+from botty.callbacks import ReplyCallback
 from botty.keyboards import InlineKeyboard
 from botty.triggers import QueryTrigger
 
@@ -9,7 +9,7 @@ from .update import UpdateHandler
 class QueryHandler(UpdateHandler):
     def __init__(
         self,
-        callback: QueryCallback,
+        callback: ReplyCallback,
         button: CallbackButton | None = None,
     ) -> None:
         self._button = button
@@ -26,5 +26,5 @@ class QueryReplyHandler(QueryHandler):
         text: str | None = None,
         keyboard: InlineKeyboard | None = None,
     ) -> None:
-        callback = QueryCallback(text, keyboard)
+        callback = ReplyCallback(text, keyboard)
         super().__init__(callback, button)
