@@ -1,4 +1,4 @@
-from botty.callbacks import TextCallback
+from botty.callbacks import ReplyCallback
 from botty.keyboards import InlineKeyboard
 from botty.triggers import StartGroupTrigger
 
@@ -6,7 +6,7 @@ from .command import CommandHandler
 
 
 class StartHandler(CommandHandler):
-    def __init__(self, callback: TextCallback) -> None:
+    def __init__(self, callback: ReplyCallback) -> None:
         super().__init__(callback, "start")
 
 
@@ -16,7 +16,7 @@ class StartReplyHandler(StartHandler):
         text: str | None = None,
         keyboard: InlineKeyboard | None = None,
     ) -> None:
-        callback = TextCallback(text, keyboard)
+        callback = ReplyCallback(text, keyboard)
         super().__init__(callback)
 
 
@@ -31,5 +31,5 @@ class StartGroupReplyHandler(StartGroupHandler):
         text: str | None = None,
         keyboard: InlineKeyboard | None = None,
     ) -> None:
-        callback = TextCallback(text, keyboard)
+        callback = ReplyCallback(text, keyboard)
         super().__init__(callback)
