@@ -1,4 +1,4 @@
-from botty.callbacks import TextCallback
+from botty.callbacks import ReplyCallback
 from botty.keyboards import InlineKeyboard
 from botty.triggers import TextTrigger
 
@@ -16,5 +16,5 @@ class TextReplyHandler(TextHandler):
         text: str | None = None,
         keyboard: InlineKeyboard | None = None,
     ) -> None:
-        callback = TextCallback(text, keyboard)
+        callback = ReplyCallback(text, keyboard)
         super().__init__(callback)
